==> activity-center-api-0.13.86-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/staticpage/StaticPageVerifyResultDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.staticpage;

import java.util.Date;

public class StaticPageVerifyResultDto {

    private Integer platformType;

    private Integer pageType;

    private Long pageId;

    private String tuiaUrl;

    private String thirdUrl;

    private Integer lastStatus;

    private Date lastSendGmt;

    private String encryptValue;

    public Integer getPlatformType() {
        return platformType;
    }

    public void setPlatformType(Integer platformType) {
        this.platformType = platformType;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public void setLastStatus(Integer lastStatus) {
        this.lastStatus = lastStatus;
    }


    public Long getPageId() {
        return pageId;
    }

    public void setPageId(Long pageId) {
        this.pageId = pageId;
    }

    public String getTuiaUrl() {
        return tuiaUrl;
    }

    public void setTuiaUrl(String tuiaUrl) {
        this.tuiaUrl = tuiaUrl;
    }

    public String getThirdUrl() {
        return thirdUrl;
    }

    public void setThirdUrl(String thirdUrl) {
        this.thirdUrl = thirdUrl;
    }

    public Integer getLastStatus() {
        return lastStatus;
    }

    public Date getLastSendGmt() {
        return lastSendGmt;
    }

    public void setLastSendGmt(Date lastSendGmt) {
        this.lastSendGmt = lastSendGmt;
    }

    public String getEncryptValue() {
        return encryptValue;
    }

    public void setEncryptValue(String encryptValue) {
        this.encryptValue = encryptValue;
    }

    @Override
    public String toString() {
        return "StaticPageVerifyResultDto{" +
                "platformType=" + platformType +
                ", pageType=" + pageType +
                ", pageId=" + pageId +
                ", tuiaUrl='" + tuiaUrl + '\'' +
                ", thirdUrl='" + thirdUrl + '\'' +
                ", lastStatus=" + lastStatus +
                ", lastSendGmt=" + lastSendGmt +
                ", encryptValue='" + encryptValue + '\'' +
                '}';
    }
}

==> activity-center-api-0.16.28-20230322.022001-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/staticpage/StaticPageVerifyResultDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.staticpage;

import java.util.Date;

public class StaticPageVerifyResultDto {

    private Long id;

    private Integer platformType;

    private Integer pageType;

    private Long pageId;

    private String tuiaUrl;

    private String thirdUrl;

    private Integer lastStatus;

    private Date lastSendGmt;

    private Date lastCallbackGmt;

    private String encryptValue;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getPlatformType() {
        return platformType;
    }

    public void setPlatformType(Integer platformType) {
        this.platformType = platformType;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public void setLastStatus(Integer lastStatus) {
        this.lastStatus = lastStatus;
    }


    public Long getPageId() {
        return pageId;
    }

    public void setPageId(Long pageId) {
        this.pageId = pageId;
    }

    public String getTuiaUrl() {
        return tuiaUrl;
    }

    public void setTuiaUrl(String tuiaUrl) {
        this.tuiaUrl = tuiaUrl;
    }

    public String getThirdUrl() {
        return thirdUrl;
    }

    public void setThirdUrl(String thirdUrl) {
        this.thirdUrl = thirdUrl;
    }

    public Integer getLastStatus() {
        return lastStatus;
    }

    public Date getLastSendGmt() {
        return lastSendGmt;
    }

    public void setLastSendGmt(Date lastSendGmt) {
        this.lastSendGmt = lastSendGmt;
    }

    public Date getLastCallbackGmt() {
        return lastCallbackGmt;
    }

    public void setLastCallbackGmt(Date lastCallbackGmt) {
        this.lastCallbackGmt = lastCallbackGmt;
    }

    public String getEncryptValue() {
        return encryptValue;
    }

    public void setEncryptValue(String encryptValue) {
        this.encryptValue = encryptValue;
    }

    @Override
    public String toString() {
        return "StaticPageVerifyResultDto{" +
                "platformType=" + platformType +
                ", pageType=" + pageType +
                ", pageId=" + pageId +
                ", tuiaUrl='" + tuiaUrl + '\'' +
                ", thirdUrl='" + thirdUrl + '\'' +
                ", lastStatus=" + lastStatus +
                ", lastSendGmt=" + lastSendGmt +
                ", lastCallbackGmt=" + lastCallbackGmt +
                ", encryptValue='" + encryptValue + '\'' +
                '}';
    }
}
